@@ -73,7 +73,7 @@ Main::Main(QWidget *)  //parent
 	connect(ui.llistat,SIGNAL(itemDoubleClicked(QListWidgetItem *)),this,SLOT(searchListWord(QListWidgetItem*)));
 	connect(ui.paraula,SIGNAL(textChanged(const QString &)),this,SLOT(paraulaChanged(const QString &)));
 
-	connect(&m_festival,SIGNAL(error(QProcess::ProcessError)),this,SLOT(FestivalError(QProcess::ProcessError)));
+	connect(&m_festival,SIGNAL(errorOccurred(QProcess::ProcessError)),this,SLOT(FestivalError(QProcess::ProcessError)));
 	connect(&m_festival,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(FestivalFinished(int,QProcess::ExitStatus)));
     connect(ui.definicio,SIGNAL(browserFailed()),this,SLOT(showBrowserError()));
 	
@@ -359,20 +359,13 @@ void Main::UpdateList() {
 	else {
 		Auxiliar::debug("File2: "+m_directori_usuari+"/"+idioma+"/"+letter+".dic");
 
-		QXmlInputSource source( &xmlFile );
-		QXmlSimpleReader reader;
-		reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",false);   //if we don't use it, we get more entries because spaces...
-		reader.setContentHandler(&handler);
+        handler.parseFile(xmlFile);
 
-		handler.setParaula(search);
+        WordData d = handler.getWordData();
 
-		reader.parse(source);
-
-		WordData d = handler.getWordData();
-
-		ui.definicio->setPlainText("");
-		m_searched=search;
-		selectItem();
+        ui.definicio->setPlainText("");
+        m_searched=search;
+        selectItem();
 	}
 }
 
@@ -386,7 +379,7 @@ void Main::setIdiomaActiu(int actiu) {
 }
 
 void Main::treballaBuscar() {
-        StructureParser handler;
+        StructureList handler;
 
        	QString buscar = ui.paraula->text();
         QString buscar_orig = ui.paraula->text();
@@ -418,17 +411,19 @@ void Main::treballaBuscar() {
 		else {
 			Auxiliar::debug("File: "+m_directori_usuari+"/"+idioma+"/"+lletra+".dic");
 
-			QXmlInputSource source( &xmlFile );
-			QXmlSimpleReader reader;
-			reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",false);   //if we don't use it, we get more entries because spaces...
-			reader.setContentHandler( &handler );
+//			QXmlInputSource source( &xmlFile );
+//			QXmlSimpleReader reader;
+//			reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",false);   //if we don't use it, we get more entries because spaces...
+//			reader.setContentHandler( &handler );
 
-			handler.setEntryWanted(buscar_orig);
+//			handler.setEntryWanted(buscar_orig);
 
-			reader.parse(source);
-
-			WordData d = handler.getWordData();
+//			reader.parse(source);
+            handler.setEntryWanted(buscar_orig);
+            handler.parseFile(xmlFile);
+            WordData d = handler.getWordData();
 
+//            WordData d;
 			ui.definicio->setPlainText("");
 
             if (d.found()) {
@@ -490,13 +485,13 @@ int Main::isValidWord(QString &q) {
 char Main::removeAccents(const QString& q) {
         QChar c = q.at(0);
 
-        if (c==L'à' || c==L'á' || c==L'â' || c==L'ä') return 'a';
-        if (c==L'è' || c==L'é' || c==L'ê' || c==L'ë') return 'e';
-        if (c==L'ì'  || c==L'í' || c==L'î' || c==L'ï') return 'i';
-        if (c==L'ò' || c==L'ó' || c==L'ô' || c==L'ö') return 'o';
-        if (c==L'ù' || c==L'ú' || c==L'û' || c==L'ü') return 'u';
+        if (c==u'à' || c==u'á' || c==u'â' || c==u'ä') return 'a';
+        if (c==u'è' || c==u'é' || c==u'ê' || c==u'ë') return 'e';
+        if (c==u'ì'  || c==u'í' || c==u'î' || c==u'ï') return 'i';
+        if (c==u'ò' || c==u'ó' || c==u'ô' || c==u'ö') return 'o';
+        if (c==u'ù' || c==u'ú' || c==u'û' || c==u'ü') return 'u';
 
-        if (q.at(0)==L'ç') return 'c';
+        if (q.at(0)==u'ç') return 'c';
 
         return (c.toLatin1());
 }
