@@ -2,7 +2,7 @@
  * This file is part of qdacco
  * qdacco: offline Dacco Catalan <-> English dictionary
  *
- * Copyright (c) 2005, 2006, 2007, 2009, 2011, 2015
+ * Copyright (c) 2005, 2006, 2007, 2009, 2011, 2015, 2021
  *      Carles Pina i Estany <carles@pina.cat>
  *
  * qdacco is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@ class Main : public QMainWindow, Ui::Main
 		Main(QWidget *parent = 0);
 
 		int UpdateList(QString &q);
-		int AddEntryToGUI(QString);
+        void AddEntryToGUI(QString);
 
 		void restaura();
 		void quit();
@@ -58,19 +58,12 @@ class Main : public QMainWindow, Ui::Main
 		void buscar();
 	
 	private:
-		
-		//TrayIcon trayicon;
-
-		//static Main* ptr_main;
-
 		HTTPConnection *m_http;
-		QProcess m_browser;
 		QProcess m_festival;
 
 		Ui::Main ui;
 
 		int m_idioma_actiu;
-		int m_numberFound;
 		int m_festival_reading;
 
 		QString m_directori_usuari;
@@ -90,7 +83,7 @@ class Main : public QMainWindow, Ui::Main
 		void posarApunt();
 		int isValidWord(QString &q);
 		void posarApunt(int all);
-		char lletra_buscar(QString q);
+        char removeAccents(const QString &q);
 		void selectItem();
 		void carrega_config(int all);
 		void obrir_configuracio();
@@ -109,7 +102,7 @@ class Main : public QMainWindow, Ui::Main
 		void moveDefinicio(QEvent *event);
 
 
-	private slots:
+    private Q_SLOTS:
 		void buscarEnter();
 		void buscarClicked();
 		void paraulaChanged(const QString &text);
@@ -130,9 +123,9 @@ class Main : public QMainWindow, Ui::Main
 		void searchListWord(QListWidgetItem *a);
 		void UpdateList();
 
-	public slots:
-		void BrowserError(QProcess::ProcessError error);
+        void showBrowserError();
 
+    public Q_SLOTS:
 		void FestivalExecuteEntry();
 		void FestivalExecuteDefinition();
 		void FestivalError(QProcess::ProcessError e);
